Allow running option roms with a wrong checksum.

Signed-off-by: Stefan Reinauer <reinauer@google.com>

diff --git a/src/Kconfig b/src/Kconfig
index fca73e4..eae59e9 100644
--- a/src/Kconfig
+++ b/src/Kconfig
@@ -244,6 +244,14 @@ menu "BIOS interfaces"
             Select this if option ROMs are already copied to
             0xc0000-0xf0000.  This must only be selected when using
             Bochs or QEMU versions older than 0.12.
+    config OPTIONROMS_FAULTY
+        depends on OPTIONROMS
+	bool "Don't ignore option ROMs with a bad checksum"
+	default n
+	help
+	    Some option ROMs in the wild have bad checksums.
+	    Say Y here to allow SeaBIOS executing them anyways.
+	    If unsure, say N.
     config PMM
         depends on OPTIONROMS
         bool "PMM interface"
diff --git a/src/optionroms.c b/src/optionroms.c
index a94b46c..4c05bf1 100644
--- a/src/optionroms.c
+++ b/src/optionroms.c
@@ -131,7 +131,8 @@ is_valid_rom(struct rom_header *rom)
     if (sum != 0) {
         dprintf(1, "Found option rom with bad checksum: loc=%p len=%d sum=%x\n"
                 , rom, len, sum);
-        return 0;
+        if (! CONFIG_OPTIONROMS_FAULTY)
+            return 0;
     }
     return 1;
 }